# Change log
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

This document follows the conventions laid out in [Keep a CHANGELOG][keep].

## [0.0.1] - 2015-10-01
### Added
* Project skeleton using "cookiecutter-pyvanguard"


[keep]: http://keepachangelog.com/
